@@ -24,6 +24,7 @@ import xmltodict
 from pydantic import BaseModel, PrivateAttr
 
 from pymetadata import log
+from pymetadata.console import console
 
 
 logger = log.get_logger(__name__)
@@ -56,6 +57,7 @@ class EntryFormat(str, Enum):
     SEDML_L1V3 = IDENTIFIERS_PREFIX + "sed-ml.level-1.version-3"
     SEDML_L1V4 = IDENTIFIERS_PREFIX + "sed-ml.level-1.version-4"
 
+    BIOPAX = IDENTIFIERS_PREFIX + "biopax"
     CELLML = IDENTIFIERS_PREFIX + "cellml"
     SBGN = IDENTIFIERS_PREFIX + "sbgn"
     SBGN_PD = IDENTIFIERS_PREFIX + "sbgn.pd"
@@ -64,201 +66,205 @@ class EntryFormat(str, Enum):
 
     MARKDOWN = PURL_PREFIX + "text/x-markdown"
     PLAIN = PURL_PREFIX + "text/plain"
+    XML = PURL_PREFIX + "application/xml"
+    RDF = PURL_PREFIX + "application/xml"
+    OWL = PURL_PREFIX + "application/xml"
+    SCI = PURL_PREFIX + "application/x-scilab"
+    XPP = PURL_PREFIX + "text/plain"
 
-    COPASI = "application/x-copasi"
-    SEDX = "application/x-sed-ml-archive"
-    PNG = "image/png"
-    CSV = "text/csv"
-    H323 = "text/h323"
-    ACX = "application/internet-property-stream"
-    AI = "application/postscript"
-    AIF = "audio/x-aiff"
-    AIFC = "audio/x-aiff"
-    AIFF = "audio/x-aiff"
-    ASF = "video/x-ms-asf"
-    ASR = "video/x-ms-asf"
-    ASX = "video/x-ms-asf"
-    AU = "audio/basic"
-    AVI = "video/x-msvideo"
-    AXS = "application/olescript"
-    BAS = "text/plain"
-    BCPIO = "application/x-bcpio"
-    BIN = "application/octet-stream"
-    BMP = "image/bmp"
-    C = "text/plain"
-    CAT = "application/vnd.ms-pkiseccat"
-    CDF = "application/x-cdf"
-    CER = "application/x-x509-ca-cert"
-    CLP = "application/x-msclip"
-    CMX = "image/x-cmx"
-    COD = "image/cis-cod"
-    CPIO = "application/x-cpio"
-    CRD = "application/x-mscardfile"
-    CRL = "application/pkix-crl"
-    CRT = "application/x-x509-ca-cert"
-    CSH = "application/x-csh"
-    CSS = "text/css"
-    DCR = "application/x-director"
-    DER = "application/x-x509-ca-cert"
-    DIR = "application/x-director"
-    DLL = "application/x-msdownload"
-    DMS = "application/octet-stream"
-    DOC = "application/msword"
-    DOT = "application/msword"
-    DVI = "application/x-dvi"
-    DXR = "application/x-director"
-    EPS = "application/postscript"
-    ETX = "text/x-setext"
-    EVY = "application/envoy"
-    EXE = "application/octet-stream"
-    FIF = "application/fractals"
-    FLR = "x-world/x-vrml"
-    GIF = "image/gif"
-    GTAR = "application/x-gtar"
-    GZ = "application/x-gzip"
-    H = "text/plain"
-    HDF = "application/x-hdf"
-    H5 = "application/x-hdf"
-    HLP = "application/winhlp"
-    HQT = "application/mac-binhex40"
-    HTA = "application/hta"
-    HTC = "text/x-component"
-    HTM = "text/html"
-    HTML = "text/html"
-    HTT = "text/webviewhtml"
-    ICO = "image/x-icon"
-    IEF = "image/ief"
-    III = "application/x-iphone"
-    INS = "application/x-internet-signup"
-    ISP = "application/x-internet-signup"
-    JFIF = "image/pipeg"
-    JPE = "image/jpeg"
-    JPEG = "image/jpeg"
-    JPG = "image/jpeg"
-    JS = "application/x-javascript"
-    LATEX = "application/x-latex"
-    LHA = "application/octet-stream"
-    LSF = "video/x-la-asf"
-    LSX = "video/x-la-asf"
-    LZH = "application/octet-stream"
-    M = "application/x-matlab"
-    MAT = "application/x-matlab-data"
-    M13 = "application/x-msmediaview"
-    M14 = "application/x-msmediaview"
-    M3U = "audio/x-mpegurl"
-    MAN = "application/x-troff-man"
-    MDB = "application/x-msaccess"
-    ME = "application/x-troff-me"
-    MHT = "message/rfc822"
-    MHTML = "message/rfc822"
-    MID = "audio/mid"
-    MNY = "application/x-msmoney"
-    MOV = "video/quicktime"
-    MOVIE = "video/x-sgi-movie"
-    MP2 = "video/mpeg"
-    MP3 = "audio/mpeg"
-    MP4 = "video/mpeg"
-    MPE = "video/mpeg"
-    MPEG = "video/mpeg"
-    MPG = "video/mpeg"
-    MPP = "application/vnd.ms-project"
-    MPV2 = "video/mpeg"
-    MS = "application/x-troff-ms"
-    MVB = "application/x-msmediaview"
-    NWS = "message/rfc822"
-    ODA = "application/oda"
-    P10 = "application/pkcs10"
-    P12 = "application/x-pkcs12"
-    P7B = "application/x-pkcs7-certificates"
-    P7C = "application/x-pkcs7-mime"
-    P7M = "application/x-pkcs7-mime"
-    P7R = "application/x-pkcs7-certreqresp"
-    P7S = "application/x-pkcs7-signature"
-    PBM = "image/x-portable-bitmap"
-    PDF = "application/pdf"
-    PFX = "application/x-pkcs12"
-    PGM = "image/x-portable-graymap"
-    PKO = "application/ynd.ms-pkipko"
-    PMA = "application/x-perfmon"
-    PMC = "application/x-perfmon"
-    PML = "application/x-perfmon"
-    PMR = "application/x-perfmon"
-    PMW = "application/x-perfmon"
-    PNW = "image/x-portable-anymap"
-    POT = "application/vnd.ms-powerpoint"
-    PPM = "image/x-portable-pixmap"
-    PPS = "application/vnd.ms-powerpoint"
-    PPT = "application/vnd.ms-powerpoint"
-    PRF = "application/pics-rules"
-    PS = "application/postscript"
-    PUB = "application/x-mspublisher"
-    QT = "video/quicktime"
-    RA = "audio/x-pn-realaudio"
-    RAM = "audio/x-pn-realaudio"
-    RAS = "image/x-cmu-raster"
-    RGB = "image/x-rgb"
-    RMI = "audio/mid"
-    ROFF = "application/x-troff"
-    RTF = "application/rtf"
-    RTX = "text/richtext"
-    SCD = "application/x-msschedule"
-    SCT = "text/scriptlet"
-    SETPAY = "application/set-payment-initiation"
-    SETREG = "application/set-registration-initiation"
-    SH = "application/x-sh"
-    SHAR = "application/x-shar"
-    SIT = "application/x-stuffit"
-    SND = "audio/basic"
-    SPC = "application/x-pkcs7-certificates"
-    SPL = "application/futuresplash"
-    SRC = "application/x-wais-source"
-    SST = "application/vnd.ms-pkicertstore"
-    STL = "application/vnd.ms-pkistl"
-    STM = "text/html"
-    SVG = "image/svg+xml"
-    SV4CPIO = "application/x-sv4cpio"
-    SV4CRC = "application/x-sv4crc"
-    SWF = "application/x-shockwave-flash"
-    T = "application/x-troff"
-    TAR = "application/x-tar"
-    TCL = "application/x-tcl"
-    TEX = "application/x-tex"
-    TEXI = "application/x-texinfo"
-    TEXINFO = "application/x-texinfo"
-    TGZ = "application/x-compressed"
-    TIF = "image/tiff"
-    TIFF = "image/tiff"
-    TR = "application/x-troff"
-    TRM = "application/x-msterminal"
-    TSV = "text/tab-separated-values"
-    TXT = "text/plain"
-    ULS = "text/iuls"
-    USTAR = "application/x-ustar"
-    VCF = "text/x-vcard"
-    VRML = "x-world/x-vrml"
-    WAV = "audio/x-wav"
-    WCM = "application/vnd.ms-works"
-    WDB = "application/vnd.ms-works"
-    WKS = "application/vnd.ms-works"
-    WMF = "application/x-msmetafile"
-    WPS = "application/vnd.ms-works"
-    WRI = "application/x-mswrite"
-    WRL = "x-world/x-vrml"
-    WRZ = "x-world/x-vrml"
-    XAF = "x-world/x-vrml"
-    XBM = "image/x-xbitmap"
-    XLA = "application/vnd.ms-excel"
-    XLC = "application/vnd.ms-excel"
-    XLM = "application/vnd.ms-excel"
-    XLS = "application/vnd.ms-excel"
-    XLT = "application/vnd.ms-excel"
-    XLW = "application/vnd.ms-excel"
-    XOF = "x-world/x-vrml"
-    XPM = "image/x-xpixmap"
-    XWD = "image/x-xwindowdump"
-    XML = "application/xml"
-    Z = "application/x-compress"
-    ZIP = "application/zip"
+    COPASI = PURL_PREFIX + "application/x-copasi"
+    SEDX = PURL_PREFIX + "application/x-sed-ml-archive"
+    PNG = PURL_PREFIX + "image/png"
+    CSV = PURL_PREFIX + "text/csv"
+    H323 = PURL_PREFIX + "text/h323"
+    ACX = PURL_PREFIX + "application/internet-property-stream"
+    AI = PURL_PREFIX + "application/postscript"
+    AIF = PURL_PREFIX + "audio/x-aiff"
+    AIFC = PURL_PREFIX + "audio/x-aiff"
+    AIFF = PURL_PREFIX + "audio/x-aiff"
+    ASF = PURL_PREFIX + "video/x-ms-asf"
+    ASR = PURL_PREFIX + "video/x-ms-asf"
+    ASX = PURL_PREFIX + "video/x-ms-asf"
+    AU = PURL_PREFIX + "audio/basic"
+    AVI = PURL_PREFIX + "video/x-msvideo"
+    AXS = PURL_PREFIX + "application/olescript"
+    BAS = PURL_PREFIX + "text/plain"
+    BCPIO = PURL_PREFIX + "application/x-bcpio"
+    BIN = PURL_PREFIX + "application/octet-stream"
+    BMP = PURL_PREFIX + "image/bmp"
+    C = PURL_PREFIX + "text/plain"
+    CAT = PURL_PREFIX + "application/vnd.ms-pkiseccat"
+    CDF = PURL_PREFIX + "application/x-cdf"
+    CER = PURL_PREFIX + "application/x-x509-ca-cert"
+    CLP = PURL_PREFIX + "application/x-msclip"
+    CMX = PURL_PREFIX + "image/x-cmx"
+    COD = PURL_PREFIX + "image/cis-cod"
+    CPIO = PURL_PREFIX + "application/x-cpio"
+    CRD = PURL_PREFIX + "application/x-mscardfile"
+    CRL = PURL_PREFIX + "application/pkix-crl"
+    CRT = PURL_PREFIX + "application/x-x509-ca-cert"
+    CSH = PURL_PREFIX + "application/x-csh"
+    CSS = PURL_PREFIX + "text/css"
+    DCR = PURL_PREFIX + "application/x-director"
+    DER = PURL_PREFIX + "application/x-x509-ca-cert"
+    DIR = PURL_PREFIX + "application/x-director"
+    DLL = PURL_PREFIX + "application/x-msdownload"
+    DMS = PURL_PREFIX + "application/octet-stream"
+    DOC = PURL_PREFIX + "application/msword"
+    DOT = PURL_PREFIX + "application/msword"
+    DVI = PURL_PREFIX + "application/x-dvi"
+    DXR = PURL_PREFIX + "application/x-director"
+    EPS = PURL_PREFIX + "application/postscript"
+    ETX = PURL_PREFIX + "text/x-setext"
+    EVY = PURL_PREFIX + "application/envoy"
+    EXE = PURL_PREFIX + "application/octet-stream"
+    FIF = PURL_PREFIX + "application/fractals"
+    FLR = PURL_PREFIX + "x-world/x-vrml"
+    GIF = PURL_PREFIX + "image/gif"
+    GTAR = PURL_PREFIX + "application/x-gtar"
+    GZ = PURL_PREFIX + "application/x-gzip"
+    H = PURL_PREFIX + "text/plain"
+    HDF = PURL_PREFIX + "application/x-hdf"
+    H5 = PURL_PREFIX + "application/x-hdf"
+    HLP = PURL_PREFIX + "application/winhlp"
+    HQT = PURL_PREFIX + "application/mac-binhex40"
+    HTA = PURL_PREFIX + "application/hta"
+    HTC = PURL_PREFIX + "text/x-component"
+    HTM = PURL_PREFIX + "text/html"
+    HTML = PURL_PREFIX + "text/html"
+    HTT = PURL_PREFIX + "text/webviewhtml"
+    ICO = PURL_PREFIX + "image/x-icon"
+    IEF = PURL_PREFIX + "image/ief"
+    III = PURL_PREFIX + "application/x-iphone"
+    INS = PURL_PREFIX + "application/x-internet-signup"
+    ISP = PURL_PREFIX + "application/x-internet-signup"
+    JFIF = PURL_PREFIX + "image/pipeg"
+    JPE = PURL_PREFIX + "image/jpeg"
+    JPEG = PURL_PREFIX + "image/jpeg"
+    JPG = PURL_PREFIX + "image/jpeg"
+    JS = PURL_PREFIX + "application/x-javascript"
+    LATEX = PURL_PREFIX + "application/x-latex"
+    LHA = PURL_PREFIX + "application/octet-stream"
+    LSF = PURL_PREFIX + "video/x-la-asf"
+    LSX = PURL_PREFIX + "video/x-la-asf"
+    LZH = PURL_PREFIX + "application/octet-stream"
+    M = PURL_PREFIX + "application/x-matlab"
+    MAT = PURL_PREFIX + "application/x-matlab-data"
+    M13 = PURL_PREFIX + "application/x-msmediaview"
+    M14 = PURL_PREFIX + "application/x-msmediaview"
+    M3U = PURL_PREFIX + "audio/x-mpegurl"
+    MAN = PURL_PREFIX + "application/x-troff-man"
+    MDB = PURL_PREFIX + "application/x-msaccess"
+    ME = PURL_PREFIX + "application/x-troff-me"
+    MHT = PURL_PREFIX + "message/rfc822"
+    MHTML = PURL_PREFIX + "message/rfc822"
+    MID = PURL_PREFIX + "audio/mid"
+    MNY = PURL_PREFIX + "application/x-msmoney"
+    MOV = PURL_PREFIX + "video/quicktime"
+    MOVIE = PURL_PREFIX + "video/x-sgi-movie"
+    MP2 = PURL_PREFIX + "video/mpeg"
+    MP3 = PURL_PREFIX + "audio/mpeg"
+    MP4 = PURL_PREFIX + "video/mpeg"
+    MPE = PURL_PREFIX + "video/mpeg"
+    MPEG = PURL_PREFIX + "video/mpeg"
+    MPG = PURL_PREFIX + "video/mpeg"
+    MPP = PURL_PREFIX + "application/vnd.ms-project"
+    MPV2 = PURL_PREFIX + "video/mpeg"
+    MS = PURL_PREFIX + "application/x-troff-ms"
+    MVB = PURL_PREFIX + "application/x-msmediaview"
+    NWS = PURL_PREFIX + "message/rfc822"
+    ODA = PURL_PREFIX + "application/oda"
+    P10 = PURL_PREFIX + "application/pkcs10"
+    P12 = PURL_PREFIX + "application/x-pkcs12"
+    P7B = PURL_PREFIX + "application/x-pkcs7-certificates"
+    P7C = PURL_PREFIX + "application/x-pkcs7-mime"
+    P7M = PURL_PREFIX + "application/x-pkcs7-mime"
+    P7R = PURL_PREFIX + "application/x-pkcs7-certreqresp"
+    P7S = PURL_PREFIX + "application/x-pkcs7-signature"
+    PBM = PURL_PREFIX + "image/x-portable-bitmap"
+    PDF = PURL_PREFIX + "application/pdf"
+    PFX = PURL_PREFIX + "application/x-pkcs12"
+    PGM = PURL_PREFIX + "image/x-portable-graymap"
+    PKO = PURL_PREFIX + "application/ynd.ms-pkipko"
+    PMA = PURL_PREFIX + "application/x-perfmon"
+    PMC = PURL_PREFIX + "application/x-perfmon"
+    PML = PURL_PREFIX + "application/x-perfmon"
+    PMR = PURL_PREFIX + "application/x-perfmon"
+    PMW = PURL_PREFIX + "application/x-perfmon"
+    PNW = PURL_PREFIX + "image/x-portable-anymap"
+    POT = PURL_PREFIX + "application/vnd.ms-powerpoint"
+    PPM = PURL_PREFIX + "image/x-portable-pixmap"
+    PPS = PURL_PREFIX + "application/vnd.ms-powerpoint"
+    PPT = PURL_PREFIX + "application/vnd.ms-powerpoint"
+    PRF = PURL_PREFIX + "application/pics-rules"
+    PS = PURL_PREFIX + "application/postscript"
+    PUB = PURL_PREFIX + "application/x-mspublisher"
+    QT = PURL_PREFIX + "video/quicktime"
+    RA = PURL_PREFIX + "audio/x-pn-realaudio"
+    RAM = PURL_PREFIX + "audio/x-pn-realaudio"
+    RAS = PURL_PREFIX + "image/x-cmu-raster"
+    RGB = PURL_PREFIX + "image/x-rgb"
+    RMI = PURL_PREFIX + "audio/mid"
+    ROFF = PURL_PREFIX + "application/x-troff"
+    RTF = PURL_PREFIX + "application/rtf"
+    RTX = PURL_PREFIX + "text/richtext"
+    SCD = PURL_PREFIX + "application/x-msschedule"
+    SCT = PURL_PREFIX + "text/scriptlet"
+    SETPAY = PURL_PREFIX + "application/set-payment-initiation"
+    SETREG = PURL_PREFIX + "application/set-registration-initiation"
+    SH = PURL_PREFIX + "application/x-sh"
+    SHAR = PURL_PREFIX + "application/x-shar"
+    SIT = PURL_PREFIX + "application/x-stuffit"
+    SND = PURL_PREFIX + "audio/basic"
+    SPC = PURL_PREFIX + "application/x-pkcs7-certificates"
+    SPL = PURL_PREFIX + "application/futuresplash"
+    SRC = PURL_PREFIX + "application/x-wais-source"
+    SST = PURL_PREFIX + "application/vnd.ms-pkicertstore"
+    STL = PURL_PREFIX + "application/vnd.ms-pkistl"
+    STM = PURL_PREFIX + "text/html"
+    SVG = PURL_PREFIX + "image/svg+xml"
+    SV4CPIO = PURL_PREFIX + "application/x-sv4cpio"
+    SV4CRC = PURL_PREFIX + "application/x-sv4crc"
+    SWF = PURL_PREFIX + "application/x-shockwave-flash"
+    T = PURL_PREFIX + "application/x-troff"
+    TAR = PURL_PREFIX + "application/x-tar"
+    TCL = PURL_PREFIX + "application/x-tcl"
+    TEX = PURL_PREFIX + "application/x-tex"
+    TEXI = PURL_PREFIX + "application/x-texinfo"
+    TEXINFO = PURL_PREFIX + "application/x-texinfo"
+    TGZ = PURL_PREFIX + "application/x-compressed"
+    TIF = PURL_PREFIX + "image/tiff"
+    TIFF = PURL_PREFIX + "image/tiff"
+    TR = PURL_PREFIX + "application/x-troff"
+    TRM = PURL_PREFIX + "application/x-msterminal"
+    TSV = PURL_PREFIX + "text/tab-separated-values"
+    TXT = PURL_PREFIX + "text/plain"
+    ULS = PURL_PREFIX + "text/iuls"
+    USTAR = PURL_PREFIX + "application/x-ustar"
+    VCF = PURL_PREFIX + "text/x-vcard"
+    VRML = PURL_PREFIX + "x-world/x-vrml"
+    WAV = PURL_PREFIX + "audio/x-wav"
+    WCM = PURL_PREFIX + "application/vnd.ms-works"
+    WDB = PURL_PREFIX + "application/vnd.ms-works"
+    WKS = PURL_PREFIX + "application/vnd.ms-works"
+    WMF = PURL_PREFIX + "application/x-msmetafile"
+    WPS = PURL_PREFIX + "application/vnd.ms-works"
+    WRI = PURL_PREFIX + "application/x-mswrite"
+    WRL = PURL_PREFIX + "x-world/x-vrml"
+    WRZ = PURL_PREFIX + "x-world/x-vrml"
+    XAF = PURL_PREFIX + "x-world/x-vrml"
+    XBM = PURL_PREFIX + "image/x-xbitmap"
+    XLA = PURL_PREFIX + "application/vnd.ms-excel"
+    XLC = PURL_PREFIX + "application/vnd.ms-excel"
+    XLM = PURL_PREFIX + "application/vnd.ms-excel"
+    XLS = PURL_PREFIX + "application/vnd.ms-excel"
+    XLT = PURL_PREFIX + "application/vnd.ms-excel"
+    XLW = PURL_PREFIX + "application/vnd.ms-excel"
+    XOF = PURL_PREFIX + "x-world/x-vrml"
+    XPM = PURL_PREFIX + "image/x-xpixmap"
+    XWD = PURL_PREFIX + "image/x-xwindowdump"
+    Z = PURL_PREFIX + "application/x-compress"
+    ZIP = PURL_PREFIX + "application/zip"
 
 
 class ManifestEntry(BaseModel):
@@ -275,10 +281,14 @@ class ManifestEntry(BaseModel):
     format: str
     master: bool = False
 
+    class Config:
+        """Pydantic configuration."""
+
+        use_enum_values = True
+
     @staticmethod
     def is_format(format_key: str, format: str) -> bool:
         """Check if entry is of the given format_key."""
-        print(format_key, format)
         if format_key == "sbml":
             return "identifiers.org/combine.specifications/sbml" in format
         if format_key == "sedml":
@@ -311,6 +321,7 @@ class Manifest(BaseModel):
     A manifest is a list of ManifestEntries.
     """
 
+    _entries_dict: Dict[str, ManifestEntry] = PrivateAttr()
     entries: List[ManifestEntry] = [
         ManifestEntry(
             location=".", format="http://identifiers.org/combine.specifications/omex"
@@ -320,10 +331,15 @@ class Manifest(BaseModel):
             format="http://identifiers.org/combine.specifications/omex-manifest",
         ),
     ]
-    _entries_dict: Dict[str, ManifestEntry] = PrivateAttr()
 
     def __init__(self, **data) -> None:  # type: ignore
         super().__init__(**data)
+        for e in self.entries:
+            if not e.location.startswith("."):
+                logger.warning(
+                    f"Relative location paths must start with './', but '{e.location}'."
+                )
+                e.location = f"./{e.location}"
         self._entries_dict = {e.location: e for e in self.entries}
 
     def __contains__(self, location: str) -> bool:
@@ -678,8 +694,10 @@ class Omex:
     def lookup_format(format_key: str) -> str:
         """Lookup format by format_key."""
         if hasattr(EntryFormat, format_key.upper()):
-            return str(getattr(EntryFormat, format_key.upper()))
-        return ""
+            return str(getattr(EntryFormat, format_key.upper()).value)
+
+        logger.error(f"Unknown format_key: {format_key}")
+        return PURL_PREFIX + "application/x.unknown"
 
     @staticmethod
     def guess_format(path: Path) -> str:
